==> tine20-allinone_2019.12.5.tar.bz2: Admin/js/Admin-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:13+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sv_SE\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "User, Users"
: [
  "Användare"
 ,"Användare"

]
, "Groups"
: "Grupper"

, "Roles"
: "Roller"

, "Applications"
: "Tillämpningar"

, "Containers"
: "Behållare"

, "Shared Tags"
: "Delade Taggar"

, "Customfields"
: "Egna fält"

, "Computers"
: "Datorer"

, "Access Log, Access Logs"
: [
  "Åtkomst Logg"
 ,"Åtkomsts Loggar"

]
, "Server Information"
: "Serverinformation"

, "ActiveSync Devices"
: ""

, "Admin"
: "Administratör"

, "Refresh"
: "Uppdatera"

, "Name"
: "Namn"

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Computer, Computers"
: [
  "Dator"
 ,"Datorer"

]
, "Default Addressbook for new contacts and groups"
: "Standard Adressbok för nya kontakter och grupper"

, "Group, Groups"
: [
  "Grupp"
 ,"Grupper"

]
, "Application, Applications"
: [
  "Tillämpning"
 ,"Tillämpningar"

]
, "Config, Configs"
: [
  ""
 ,""

]
, "Configs"
: ""

, "Please wait"
: "Vänligen vänta"

, "Updating Memberships"
: "Uppdatera medlemsskap"

, "Failed"
: "Misslyckades"

, "Could not save group."
: "Kunde inte spara grupp."

, "Errors"
: "Fel"

, "Please fix the errors noted."
: "Åtgärda felen som noterats."

, "Group Name"
: "Grupp Namn"

, "Description"
: "Beskrivning"

, "Visibility"
: "Synlighet"

, "Display in addressbook"
: "Visa i adressbok"

, "Hide from addressbook"
: "Dölj från adressbok"

, "Saved in Addressbook"
: "Spara i Adressbok"

, "Group Members"
: "Grupp Medlemmar"

, "Transferring {0}..."
: "Överför {0}..."

, "Add new group"
: "Lägg till ny grupp"

, "Edit Group \"{0}\""
: "Ändra Grupp \"{0}\""

, "Enable Application"
: "Aktivera applikation"

, "Disable Application"
: "Avaktivera applikation"

, "Settings"
: "Inställningar"

, "{0} Settings"
: "{0} Inställningar"

, "enable application"
: "aktivera tillämpning"

, "disable application"
: "avaktivera tillämpning"

, "settings"
: "inställningar"

, "Search:"
: "Sök:"

, "disabled"
: "avaktiverad"

, "enabled"
: "aktiverad"

, "unknown status ({0})"
: "okänd status ({0})"

, "Displaying application {0} - {1} of {2}"
: "Visar tillämpning {0} - {1} av {2}"

, "No applications to display"
: "Inga tillämpningar att visa"

, "Order"
: "Beställ"

, "Status"
: "Status"

, "Version"
: "Version"

, "Confirm"
: "Bekräfta"

, "Do you really want to delete the selected groups?"
: "Vill du verkligen ta bort valda grupper?"

, "Deleting group(s)..."
: "Ta bort grupp(er)..."

, "Some error occurred while trying to delete the group."
: "Några fel uppstod vid försök att ta bort gruppen."

, "Add Group"
: "Lägg till grupp"

, "Edit Group"
: "Editera grupp"

, "Delete Group"
: "Radera grupp"

, "Displaying groups {0} - {1} of {2}"
: "Visar grupper {0} - {1} av {2}"

, "No groups to display"
: "Inga grupper att visa"

, "ID"
: "ID"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Computer Name"
: "Dator Namn"

, "IP Address"
: "IP Adress"

, "Login Time"
: "Inloggningstid Tid"

, "Logout Time"
: "Utloggningstid Tid"

, "Client Type"
: "Klient Typ"

, "Session ID"
: "Sessions ID"

, "Login Name"
: "Inloggnings Namn"

, "Result"
: "Resultat"

, "user blocked"
: "Användare blockad"

, "password expired"
: "lösenord utgått"

, "user disabled"
: "användare inatkiverad"

, "invalid password"
: "ogiltligt lösenord"

, "ambiguous username"
: "tvetydligt användarnamn"

, "user not found"
: "användare inte hittad"

, "failure"
: "misslyckande"

, "success"
: "framsteg"

, "Could not save role."
: "Kunde inte spara roll."

, "Deleting role..."
: "Tar bort roll..."

, "Some error occurred while trying to delete the role."
: "Några fel uppstod vid försök att ta bort gruppen."

, "Rights"
: "Rättigheter"

, "Members"
: "Medlemmar"

, "Role Name"
: "Roll Namn"

, "Role"
: "Roll"

, "Add New Role"
: "Lägg Till Ny Roll"

, "Edit Role \"{0}\""
: "Ändra Roll \"{0}\""

, "Container Name"
: "Behållare Namn"

, "Type"
: "Typ"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Behållare"
 ,"Behållare"

]
, "Model"
: "Modell"

, "personal"
: "personlig"

, "shared"
: "Delad"

, "Color"
: "Färg"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Notering för Ägare"

, "Do you really want to delete the selected roles?"
: "Vill du verkligen ta bort dom valda rollerna?"

, "Deleting role(s)..."
: "tar bort roll(er)..."

, "Add Role"
: "Lägg till roll"

, "Edit Role"
: "Editera roll"

, "Delete Role"
: "Radera roll"

, "Displaying roles {0} - {1} of {2}"
: "Visar roller {0} - {1} av {2}"

, "No roles to display"
: "Inga roller att visa"

, "Do you really want to delete the selected tags?"
: "Vill du verkligen ta bort valda taggar?"

, "Deleting tag(s)..."
: "Tar bort tagg(ar)..."

, "Add Tag"
: "Lägg till tagg"

, "Edit Tag"
: "Editera tagg"

, "Delete Tag"
: "Radera tagg"

, "Displaying tags {0} - {1} of {2}"
: "Visar taggar {0} - {1} av {2}"

, "No tags to display"
: "Inga taggar att visa"

, "Usage:&#160;"
: "Användande:&#160;"

, "Label"
: "Märke"

, "Value"
: "Värde"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Customfield, Customfields"
: [
  "Eget fält"
 ,"Egna fält"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Please configure store for this field type"
: "Konfigurera butiken för denna filtyp"

, "Record Class"
: "Post Klass"

, "Given record class not found"
: "Given post klass inte funnen"

, "Cancel"
: "Avbryt"

, "OK"
: "OK"

, "Configure store"
: "Konfigurations butik"

, "Custom field definition"
: "Eget fält betydelse"

, "Text"
: "Text"

, "Textarea"
: ""

, "Number"
: "Nummer"

, "Date"
: "Datum"

, "DateTime"
: "Datumtid"

, "Time"
: "Tid"

, "Boolean"
: "Boolean"

, "Search Combo"
: "Sökkombination"

, "Key Field"
: "Nyckelfält"

, "Record"
: "Record"

, "Record List"
: ""

, "Length"
: "Längd"

, "Required"
: "Krävs"

, "Custom field additional properties"
: "Ytterligare inställningar för anpassade fält"

, "Tab Panel"
: ""

, "Customfield already exists. Please choose another name."
: "Anpassade fältet existerar redan. Vänligen välj ett annat namn."

, "Enable Account"
: "Aktivera konto"

, "Disable Account"
: "Avaktivera konto"

, "Reset Password"
: "Återställ lösenord"

, "Reset Pin"
: ""

, "Display name"
: "Visningsnamn"

, "Login name"
: "Inloggningsnamn"

, "Last name"
: "Efternamn"

, "First name"
: "Förnamn"

, "Email"
: "E-post"

, "Email usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "ÖppnaID"

, "Last login at"
: "Senaste Inloggning"

, "Last login from"
: "Senaste Inloggning från"

, "Password changed"
: "Lösenord ändrat"

, "Expires"
: "Utgår"

, "Set new password"
: "Välj nytt lösenord"

, "Please enter the new password:"
: "Ange nytt lösenord"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Users"
: "Användare"

, "Samba User, Samba Users"
: [
  "Samba Användare"
 ,"Samba Användare"

]
, "Email User, Email Users"
: [
  "E-post Användare"
 ,"E-post Användare"

]
, "Domain is not allowed. Check your SMTP domain configuration."
: "Domän ej tillåten. Kontrollera konfigurationen för SMTP-domänen."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Lösenorden matchar inte!"

, "Passwords match!"
: "Lösenorden matchar!"

, "Primary group"
: "Primär grupp"

, "Unix"
: "Unix"

, "Home Directory"
: "Hemmamapp"

, "Login Shell"
: "Inloggningsskal"

, "Windows"
: "Windows"

, "Home Drive"
: "Hemmadisk"

, "Logon Time"
: "Påloggningstid"

, "never logged in"
: "loggade inte in"

, "Home Path"
: "Sökväg för hem"

, "Logoff Time"
: "Avloggningstid"

, "never logged off"
: "loggade inte av"

, "Profile Path"
: "Sökväg för profil"

, "Password Last Set"
: "Ändrade lösenord senast"

, "never"
: "aldrig"

, "Logon Script"
: "Inloggningsscript"

, "Password Can Change"
: "Lösenordet kan ändras"

, "not set"
: "inte inställt"

, "Password Must Change"
: "Lösenord måste ändras"

, "Kick Off Time"
: "Tid för avspark"

, "Filesystem Quota"
: ""

, "Quota"
: "Kvot"

, "no quota set"
: "ingen kvot satt"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Nuvarande storlek på e-postmappen"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Nuvarande kvot"

, "Information"
: "Information"

, "Last Login"
: "Senast inloggad"

, "Domain not allowed"
: "Domän inte tillåten"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Email Alias"
: "E-postalias"

, "Add an alias address..."
: "Lägg till ett alias.."

, "Forwarding to self"
: "Vidarebefodran till sig själv"

, "You are not allowed to set a forward email address that is identical to the users primary email or one of his aliases."
: "Du tillåts inte att sätta en vidarebefodrans-adress som är identisk med användarens primära adress eller ett av användares alias."

, "Email Forward"
: "Vidarebefordra e-post"

, "Add a forward address..."
: "Lägg till en vidarebefordringsadress..."

, "Forward Only"
: "Vidarebefordra endast"

, "Password confirmation"
: "Lösenordskonfirmation"

, "Repeat password"
: "Repetera lösenord"

, "Ok"
: "Ok"

, "Account"
: "Konto"

, "Password"
: "Lösenord"

, "expired"
: "utgången"

, "blocked"
: "blockerad"

, "Invalid Status"
: "Ogiltig Status"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Blockerade status är endast giltigt om användaren försökte logga in med fel lösenord för ofta. Det är inte möjligt att ställa in denna status här."

, "don't know"
: "vet inte"

, "Password set"
: "Lösenord Satt"

, "User groups"
: "Användar grupper"

, "User roles"
: "Användar roller"

, "Fileserver"
: "Filserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Updating Tag"
: "Updaterings Tagg"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Tillåtna Sammanhang"

, "Context"
: "Sammanhang"

, "Account Rights"
: "Konto Rättigheter"

, "View"
: "Visa "

, "Use"
: "Använda"

, "Tag Name"
: "Tagg Namn"

, "Tag"
: "Tagg"

, "Add New Tag"
: "Lägg till ny tagg"

, "Edit Tag \"{0}\""
: "Ändra Tagg \"{0}\""

, "Default IMAP user settings"
: "Standard IMAP-inställningar för användare"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "manage access log"
: "hantera åtkomstlogg"

, "delete access log entries"
: "radera åtkomstlogg"

, "manage accounts"
: "hantera konton"

, "add and edit users and groups, add group members, change user passwords"
: "lägga till och redigera användare och grupper, lägga till gruppmedlemmar, ändra lösenord för användare"

, "manage applications"
: "hantera applikationer"

, "enable and disable applications, edit application settings"
: "aktivera och inaktivera applikationer, redigera applikationinställningar"

, "manage roles"
: "hantera roller"

, "add and edit roles, add new members to roles, add application rights to roles"
: "lägga till och redigera roller, lägga till nya medlemmar till roller, lägga till applikationsrättigheter till roller"

, "manage shared tags"
: "hantera delade taggar"

, "add, delete and edit shared tags"
: "lägga till, radera och redigera delade taggar"

, "manage computers"
: "hantera datorer"

, "add, delete and edit (samba) computers"
: "lägg till, radera och redigera (samba) datorer"

, "manage containers"
: "hantera behållare"

, "add, delete and edit containers and manage container grants"
: "lägga till, radera och redigera behållare och hantera rättigheter"

, "manage customfields"
: ""

, "add and edit customfields"
: ""

, "view access log"
: "visa åtkomst logg"

, "view access log list"
: "visa åtkomst logg lista"

, "view accounts"
: "visa konton"

, "view accounts list and details"
: "visa konto listor och detaljer"

, "view applications"
: "visa tillämpningar"

, "view applications list and details"
: "visa tillämpningars listor och detaljer"

, "view roles"
: "visa roller"

, "view roles list and details"
: "visa rollers lista och detaljer"

, "view computers"
: "visa datorer"

, "view computers list and details"
: "visa dator listor och detaljer"

, "view containers"
: "visa behållare"

, "view personal and shared containers"
: "visa personliga och delade behållare"

, "view customfields"
: ""

, "view customfields list"
: ""

, "view serverinfo"
: ""

, "view serverinfo list"
: ""

, "view quota usage"
: ""

, "Your container has been changed"
: "Din behållare har blivit ändrad"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Din behållare har blivit ändrad av %1$s %2$sNotering: %3$s"

, "Could not save tag without (view-)rights"
: ""

, "User"
: "Användare"

, "Access Log"
: "Åtkomst Logg"

, "Computer"
: "Dator"

, "Group"
: "Grupp"

, "Application"
: "Tillämpning"

, "Config"
: ""

, "Container"
: "Behållare"

, "Customfield"
: "Eget fält"

, "Samba User"
: "Samba Användare"

, "Email User"
: "E-post Användare"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 12:13+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: "Aktivera applikation"

, "Disable Application"
: "Avaktivera applikation"

, "Settings"
: "Inställningar"

, "{0} Settings"
: "{0} Inställningar"

, "Search:"
: "Sök:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Visar tillämpning {0} - {1} av {2}"

, "No applications to display"
: "Inga tillämpningar att visa"

, "Order"
: "Beställ"

, "Name"
: "Namn"

, "Status"
: "Status"

, "Version"
: "Version"

, "Confirm"
: "Bekräfta"

, "Do you really want to delete the selected groups?"
: "Vill du verkligen ta bort valda grupper?"

, "Deleting group(s)..."
: "Ta bort grupp(er)..."

, "Failed"
: "Misslyckades"

, "Some error occurred while trying to delete the group."
: "Några fel uppstod vid försök att ta bort gruppen."

, "Add Group"
: "Lägg till grupp"

, "Edit Group"
: "Editera grupp"

, "Delete Group"
: "Radera grupp"

, "Displaying groups {0} - {1} of {2}"
: "Visar grupper {0} - {1} av {2}"

, "No groups to display"
: "Inga grupper att visa"

, "ID"
: "ID"

, "E-mail"
: ""

, "Description"
: "Beskrivning"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Fel"

, "Please configure store for this field type"
: "Konfigurera butiken för denna filtyp"

, "Application, Applications"
: [
  "Tillämpning"
 ,"Tillämpningar"

]
, "Record Class"
: "Post Klass"

, "Given record class not found"
: "Given post klass inte funnen"

, "Cancel"
: "Avbryt"

, "OK"
: "OK"

, "Configure store"
: "Konfigurations butik"

, "Model"
: "Modell"

, "Custom field definition"
: "Eget fält betydelse"

, "Text"
: "Text"

, "Textarea"
: ""

, "Number"
: "Nummer"

, "Date"
: "Datum"

, "DateTime"
: "Datumtid"

, "Time"
: "Tid"

, "Boolean"
: "Boolean"

, "Search Combo"
: "Sökkombination"

, "Key Field"
: "Nyckelfält"

, "Record"
: "Record"

, "Record List"
: ""

, "Type"
: "Typ"

, "Label"
: "Märke"

, "Length"
: "Längd"

, "Required"
: "Krävs"

, "Custom field additional properties"
: "Ytterligare inställningar för anpassade fält"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Grupp"
 ,"Grupper"

]
, "Customfield already exists. Please choose another name."
: "Anpassade fältet existerar redan. Vänligen välj ett annat namn."

, "Customfield, Customfields"
: [
  "Eget fält"
 ,"Egna fält"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: "Värde"

, "Default ({0})"
: ""

, "Computer Name"
: "Dator Namn"

, "Default Addressbook for new contacts and groups"
: "Standard Adressbok för nya kontakter och grupper"

, "Please wait"
: "Vänligen vänta"

, "Updating Tag"
: "Updaterings Tagg"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Åtgärda felen som noterats."

, "Allowed Contexts"
: "Tillåtna Sammanhang"

, "Context"
: "Sammanhang"

, "Account Rights"
: "Konto Rättigheter"

, "View"
: "Visa "

, "Use"
: "Använda"

, "Tag Name"
: "Tagg Namn"

, "Color"
: "Färg"

, "Transferring {0}..."
: "Överför {0}..."

, "Tag"
: "Tagg"

, "Add New Tag"
: "Lägg till ny tagg"

, "Edit Tag \"{0}\""
: "Ändra Tagg \"{0}\""

, "Do you really want to delete the selected tags?"
: "Vill du verkligen ta bort valda taggar?"

, "Deleting tag(s)..."
: "Tar bort tagg(ar)..."

, "Add Tag"
: "Lägg till tagg"

, "Edit Tag"
: "Editera tagg"

, "Delete Tag"
: "Radera tagg"

, "Displaying tags {0} - {1} of {2}"
: "Visar taggar {0} - {1} av {2}"

, "No tags to display"
: "Inga taggar att visa"

, "Usage:&#160;"
: "Användande:&#160;"

, "Updating Memberships"
: "Uppdatera medlemsskap"

, "Could not save role."
: "Kunde inte spara roll."

, "Deleting role..."
: "Tar bort roll..."

, "Some error occurred while trying to delete the role."
: "Några fel uppstod vid försök att ta bort gruppen."

, "Rights"
: "Rättigheter"

, "Members"
: "Medlemmar"

, "Role Name"
: "Roll Namn"

, "Role"
: "Roll"

, "Add New Role"
: "Lägg Till Ny Roll"

, "Edit Role \"{0}\""
: "Ändra Roll \"{0}\""

, "Do you really want to delete the selected roles?"
: "Vill du verkligen ta bort dom valda rollerna?"

, "Deleting role(s)..."
: "tar bort roll(er)..."

, "Add Role"
: "Lägg till roll"

, "Edit Role"
: "Editera roll"

, "Delete Role"
: "Radera roll"

, "Displaying roles {0} - {1} of {2}"
: "Visar roller {0} - {1} av {2}"

, "No roles to display"
: "Inga roller att visa"

, "Access Log, Access Logs"
: [
  "Åtkomst Logg"
 ,"Åtkomsts Loggar"

]
, "Groups"
: "Grupper"

, "Applications"
: "Tillämpningar"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domän ej tillåten. Kontrollera konfigurationen för SMTP-domänen."

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Lösenorden matchar inte!"

, "Passwords match!"
: "Lösenorden matchar!"

, "Primary group"
: "Primär grupp"

, "Unix"
: "Unix"

, "Home Directory"
: "Hemmamapp"

, "Login Shell"
: "Inloggningsskal"

, "Windows"
: "Windows"

, "Home Drive"
: "Hemmadisk"

, "Login Time"
: "Inloggningstid Tid"

, "never logged in"
: "loggade inte in"

, "Home Path"
: "Sökväg för hem"

, "Logout Time"
: "Utloggningstid Tid"

, "never logged off"
: "loggade inte av"

, "Profile Path"
: "Sökväg för profil"

, "Password Last Set"
: "Ändrade lösenord senast"

, "never"
: "aldrig"

, "Logon Script"
: "Inloggningsscript"

, "Password Can Change"
: "Lösenordet kan ändras"

, "not set"
: "inte inställt"

, "Password Must Change"
: "Lösenord måste ändras"

, "Kick Off Time"
: "Tid för avspark"

, "Filesystem Quota"
: ""

, "Quota"
: "Kvot"

, "no quota set"
: "ingen kvot satt"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Nuvarande storlek på e-postmappen"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Nuvarande kvot"

, "Information"
: "Information"

, "Last Login"
: "Senast inloggad"

, "Domain not allowed"
: "Domän inte tillåten"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Lägg till ett alias.."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: "Vidarebefodran till sig själv"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Vidarebefordra endast"

, "Password confirmation"
: "Lösenordskonfirmation"

, "Repeat password"
: "Repetera lösenord"

, "Ok"
: "Ok"

, "Account"
: "Konto"

, "First name"
: "Förnamn"

, "Last name"
: "Efternamn"

, "Login name"
: "Inloggningsnamn"

, "Password"
: "Lösenord"

, "OpenID"
: "ÖppnaID"

, "enabled"
: "aktiverad"

, "disabled"
: "avaktiverad"

, "expired"
: "utgången"

, "blocked"
: "blockerad"

, "Invalid Status"
: "Ogiltig Status"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Blockerade status är endast giltigt om användaren försökte logga in med fel lösenord för ofta. Det är inte möjligt att ställa in denna status här."

, "Expires"
: "Utgår"

, "Visibility"
: "Synlighet"

, "Display in addressbook"
: "Visa i adressbok"

, "Hide from addressbook"
: "Dölj från adressbok"

, "Saved in Addressbook"
: "Spara i Adressbok"

, "Last login at"
: "Senaste Inloggning"

, "don't know"
: "vet inte"

, "Last login from"
: "Senaste Inloggning från"

, "Password set"
: "Lösenord Satt"

, "User groups"
: "Användar grupper"

, "User roles"
: "Användar roller"

, "Fileserver"
: "Filserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Användare"
 ,"Användare"

]
, "Users"
: "Användare"

, "Samba User, Samba Users"
: [
  "Samba Användare"
 ,"Samba Användare"

]
, "Email User, Email Users"
: [
  "E-post Användare"
 ,"E-post Användare"

]
, "Enable Account"
: "Aktivera konto"

, "Disable Account"
: "Avaktivera konto"

, "Reset Password"
: "Återställ lösenord"

, "Reset Pin"
: ""

, "Display name"
: "Visningsnamn"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "Lösenord ändrat"

, "Set new password"
: "Välj nytt lösenord"

, "Please enter the new password:"
: "Ange nytt lösenord"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Grupp Namn"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Grupp Medlemmar"

, "personal"
: "personlig"

, "shared"
: "Delad"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Notering för Ägare"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  "Behållare"
 ,"Behållare"

]
, "Container Name"
: "Behållare Namn"

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Dator"
 ,"Datorer"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Roller"

, "Containers"
: "Behållare"

, "Shared Tags"
: "Delade Taggar"

, "Customfields"
: "Egna fält"

, "Computers"
: "Datorer"

, "Server Information"
: "Serverinformation"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Administratör"

, "Refresh"
: "Uppdatera"

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP Adress"

, "Client Type"
: "Klient Typ"

, "Session ID"
: "Sessions ID"

, "Login Name"
: "Inloggnings Namn"

, "Result"
: "Resultat"

, "user blocked"
: "Användare blockad"

, "password expired"
: "lösenord utgått"

, "user disabled"
: "användare inatkiverad"

, "invalid password"
: "ogiltligt lösenord"

, "ambiguous username"
: "tvetydligt användarnamn"

, "user not found"
: "användare inte hittad"

, "failure"
: "misslyckande"

, "success"
: "framsteg"

, "Default IMAP user settings"
: "Standard IMAP-inställningar för användare"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Din behållare har blivit ändrad"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Din behållare har blivit ändrad av %1$s %2$sNotering: %3$s"

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""









































, "Application"
: "Tillämpning"

, "Group"
: "Grupp"

, "Customfield"
: "Eget fält"

, "Config"
: ""

, "Access Log"
: "Åtkomst Logg"

, "User"
: "Användare"

, "Samba User"
: "Samba Användare"

, "Email User"
: "E-post Användare"

, "Container"
: "Behållare"

, "Computer"
: "Dator"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
